@@ -1,6 +1,6 @@
 package Locale::Babelfish;
 
-# ABSTRACT: Perl I18n using github://nodeca/babelfish format.
+# ABSTRACT: Perl I18n using https://github.com/nodeca/babelfish format.
 
 
 use utf8;
@@ -18,33 +18,50 @@ use Locale::Babelfish::Phrase::Compiler ();
 
 use parent qw( Class::Accessor::Fast );
 
-our $VERSION = '1.000000'; # VERSION
+use constant {
+    MTIME_INDEX => 9,
+};
+
+our $VERSION = '1.000001'; # VERSION
 
 __PACKAGE__->mk_accessors( qw(
     dictionaries
     fallbacks
     fallback_cache
     dirs
-    _suffix
+    suffix
     default_locale
     file_filter
+    watch
+    watchers
 ) );
 
 my $parser = Locale::Babelfish::Phrase::Parser->new();
 my $compiler = Locale::Babelfish::Phrase::Compiler->new();
 
 
-sub new {
-    my ( $class, $cfg ) = @_;
-    $cfg //= {};
-    my $self = bless {
+sub _built_config {
+    my ( $cfg ) = @_;
+    return {
         dictionaries   => {},
         dirs           => [ "./locales" ],
         fallbacks      => {},
         fallback_cache => {},
-        _suffix        => $cfg->{suffix} // 'yaml',
+        suffix         => $cfg->{suffix} // 'yaml',
         default_locale => $cfg->{default_locale} // 'en_US',
-        %{ $cfg },
+        watch          => $cfg->{watch} || 0,
+        watchers       => {},
+        %{ $cfg // {} },
+    };
+}
+
+
+sub new {
+    my ( $class, $cfg ) = @_;
+
+    my $self = bless {
+        _cfg => $cfg,
+        %{ _built_config( $cfg ) },
     }, $class;
 
     $self->load_dictionaries( $self->file_filter );
@@ -101,25 +118,26 @@ sub load_dictionaries {
     my ( $self, $filter ) = @_;
 
     for my $dir ( @{$self->dirs} ) {
+        my $fdir = File::Spec->rel2abs( $dir );
         find( {
             follow   => 1,
             no_chdir => 1,
             wanted   => sub {
                 my $file = File::Spec->rel2abs( $File::Find::name );
                 return  unless -f $file;
+                return  if $filter && !$filter->($file);
+
                 my ( $volume, $directories, $base ) = File::Spec->splitpath( $file );
 
-                return  if $filter && !$filter->($file);
 
                 my @tmp = split m/\./, $base;
 
                 my $cur_suffix = pop @tmp;
-                return  if $cur_suffix ne $self->_suffix;
+                return  if $cur_suffix ne $self->suffix;
                 my $locale = pop @tmp;
 
                 my $dictname = join('.', @tmp);
                 my $subdir = File::Spec->catpath( $volume, $directories, '' );
-                my $fdir = File::Spec->rel2abs( $dir );
                 if ( $subdir =~ m/\A\Q$fdir\E[\\\/](.+)\z/) {
                     $dictname = "$1$dictname";
                 }
@@ -141,6 +159,10 @@ sub _load_dictionary {
     my $yaml = LoadFile( $file );
 
     _flat_hash_keys( $yaml, "$dictname.", $self->dictionaries->{$lang} );
+
+    return  unless $self->watch;
+
+    $self->watchers->{$file} = (stat($file))[MTIME_INDEX];
 }
 
 
@@ -154,6 +176,35 @@ sub phrase_need_compilation {
 }
 
 
+sub on_watcher_change {
+    my ( $self ) = @_;
+    delete $self->{keys %$self};
+    my %new_cfg = %{ _built_config( $self->{_cfg} ) };
+    while( my ( $key, $value ) = each %new_cfg ) {
+        $self->{$key} = $value;
+    }
+    $self->load_dictionaries;
+    $self->locale( $self->{default_locale} );
+}
+
+
+
+sub check_for_changes {
+    my ( $self ) = @_;
+    return  unless $self->{watch};
+    my $ok = 1;
+    while ( my ( $file, $mtime ) = each %{ $self->watchers } ) {
+        my $new_mtime = (stat($file))[MTIME_INDEX];
+        if ( !defined( $mtime ) || !defined( $new_mtime ) || $new_mtime != $mtime ) {
+            $ok = 0;
+            last;
+        }
+    }
+    return  if $ok;
+    $self->on_watcher_change();
+}
+
+
 sub t_or_undef {
     my ( $self, $dictname_key, $params, $custom_locale ) = @_;
 
@@ -288,11 +339,11 @@ __END__
 
 =head1 NAME
 
-Locale::Babelfish - Perl I18n using github://nodeca/babelfish format.
+Locale::Babelfish - Perl I18n using https://github.com/nodeca/babelfish format.
 
 =head1 VERSION
 
-version 1.000000
+version 1.000001
 
 =head1 SYNOPSIS
 
@@ -388,6 +439,20 @@ Loads dictionaries recursively on specified path.
 
 Is phrase need parsing and compilation.
 
+=head2 on_watcher_change
+
+    $self->on_watcher_change()
+
+Reloads all dictionaries.
+
+=head2 check_for_changes
+
+    $self->check_for_changes()
+
+Checks that all files unchanged or calls L</on_watcher_change>.
+
+Works when watch option set only.
+
 =head2 t_or_undef
 
 Get internationalized value for key from dictionary.
@@ -485,6 +550,10 @@ Result will be executed when coderef.
 
 Scalar/hashref/arrayref will be returned as is.
 
+Watch option supported.
+
+=for Pod::Coverage _built_config
+
 =for Pod::Coverage _load_dictionary
 
 =for Pod::Coverage _flat_hash_keys
